<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Name</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>退出程式</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Display help </source>
        <translation>顯示說明</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="91"/>
        <source>Help</source>
        <translation>說明</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>Back</source>
        <translation>上一步</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Next</source>
        <translation>下一步</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>About this application</source>
        <translation>關於本程式</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>About...</source>
        <translation>關於……</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>View Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="259"/>
        <location filename="../mainwindow.cpp" line="490"/>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>Select ISO</source>
        <translation>選擇 ISO 檔</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="270"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;選擇標的 USB 設備 Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;選擇 ISO 檔&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="309"/>
        <source>Advanced Options</source>
        <translation>進階選項</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="327"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>即便目標上已有 ext4 檔案系統，仍然製作該檔案系統</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>更新 usb 現場版的時候，保存原本的 boot 目錄</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>採用 gpt 磁碟區，不採用 msdos 磁碟區</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="344"/>
        <source>GPT partitioning</source>
        <translation>GPT 磁碟區</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>更新檔案（只是更新既有的 usb 現場版）</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>不取代原本的 syslinux 檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="361"/>
        <source>Keep syslinux files</source>
        <translation>保留 syslinux 檔</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <source>Ignore USB/removable check</source>
        <translation>跳過不檢查 USB 與可抽取之設備</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Temporarily disable automounting</source>
        <translation>暫時凍結自動掛載功能</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>設定 pmbr_boot 磁碟旗標（無法透過 UEFI 開機）</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>ESP (uefi) 磁碟區大小：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="438"/>
        <source>Verbosity (less to more):</source>
        <translation>詳細程度（由低至高）：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="487"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>Make separate data partition (percent)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Refresh drive list</source>
        <translation>更新磁碟清單</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="547"/>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Show advanced options</source>
        <translation>顯示進階選項</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="567"/>
        <source>Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="582"/>
        <source>Full-featured mode - writable Li&amp;veUSB</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>唯讀，不可用於持續版的映像檔</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="595"/>
        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <source>Options</source>
        <translation>選項</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="695"/>
        <source>Percent of USB-device to use:</source>
        <translation>動用 USB 設備的多少百分比：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="702"/>
        <source>Label ext partition:</source>
        <translation>ext 磁碟區的標籤：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>一切會影響到 usb 設備的命令，均不執行</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>Dry run (no change to system)</source>
        <translation>排演（不動到系統）</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>從掛載在系統上的現場版 usb，或者 iso 檔，進行複製。</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Clone an existing live system</source>
        <translation>複製既有的現場系統</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="770"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>進行設定，以從加密的磁碟區開機；首次開機時，會請你輸入密碼（pass phrase）</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="773"/>
        <source>Encrypt</source>
        <translation>加密</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="780"/>
        <source>Clone running live system</source>
        <translation>複製正在運行的現場系統</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="76"/>
        <source>Confirmation</source>
        <translation>確認</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="77"/>
        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <location filename="../mainwindow.cpp" line="306"/>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Failure</source>
        <translation>失敗</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>讀取的來源與寫入的目標乃是同一個設備，請重新選擇。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <source>Writing %1 using 'dd' command to /dev/%2,

Please wait until the the process is completed</source>
        <translation>正在利用「dd」命令將 %1 寫入 /dev/%2，

請等待程序執行完畢</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="301"/>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="301"/>
        <source>LiveUSB creation successful!</source>
        <translation>現場版 USB 製作成功！</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>製作現場版 USB 的程序發生錯誤</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>Please select a USB device to write to</source>
        <translation>請選擇要寫入哪一個 USB 設備</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>These actions will destroy all data on 

</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>Do you wish to continue?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <location filename="../mainwindow.cpp" line="504"/>
        <source>clone</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="399"/>
        <source>About %1</source>
        <translation>大約 %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="400"/>
        <source>Version: </source>
        <translation>版本：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>本程式可以製作現場版 usb，其資料來源可以是 iso 檔、另外一個現場版 usb、現場版 cd/dvd、正在運行的系統。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>Copyright (c) MX Linux</source>
        <translation>版權所有 (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="404"/>
        <source>%1 License</source>
        <translation>%1 許可</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>%1 Help</source>
        <translation>%1 幫助</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>選擇要用哪個 ISO 檔來寫入 USB 設備</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="430"/>
        <location filename="../mainwindow.cpp" line="486"/>
        <source>Select Source Directory</source>
        <translation>選擇資料來源目錄</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>找不到 %1/antiX/linuxfs 檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>Hide advanced options</source>
        <translation>隱藏進階選項</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="485"/>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Select Source</source>
        <translation>選擇來源</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="489"/>
        <location filename="../mainwindow.cpp" line="509"/>
        <source>Select ISO file</source>
        <translation>選擇 ISO 檔</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="576"/>
        <source>Could not find a log file at: </source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation>授權條款</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>變更紀錄</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>關閉（&amp;C）</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>本程式可以製作現場版 usb，其資料來源可以是 iso 檔、另外一個現場版 usb、現場版 cd/dvd、正在運行的系統。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>filename</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Name of .iso file to open</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>[filename]</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="78"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>version:</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>